@@ -1,9 +1,23 @@
 /*
- * Sudoku: A plugin for the Video Disk Recorder
+ * Sudoku: A plug-in for the Video Disk Recorder
  *
- * See the README file for copyright information and how to reach the author.
+ * Copyright (C) 2005-2008, Thomas Gnther <tom@toms-cafe.de>
  *
- * $Id: setup.h 19 2005-11-03 21:54:19Z tom $
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * $Id: setup.h 117 2008-03-21 17:57:50Z tom $
  */
 
 #ifndef VDR_SUDOKU_SETUP_H
@@ -26,6 +40,8 @@ namespace SudokuPlugin
     int symmetric;
     int mark_errors;
     int mark_ambiguous;
+    int show_possibles_pattern;
+    int show_possibles_digits;
     int clear_marks;
     int transparency;
 
